api.datastores.v1.store package — Argus-Toolbelt 1.0 documentation

# api.datastores.v1.store package

## Submodules

## api.datastores.v1.store.store module

Autogenerated API

`api.datastores.v1.store.store.` `delete_data_store_entries`(dataStore: str, key: list = None, customerID: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Deletes the specified datastore entries for the specified store. (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name key (list) – Datastore keys to delete customerID (int) – Specify datastore to delete entries from (default is users customer)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 342, “limit”: 169, “responseCode”: 200, “count”: 511, “data”: [{“dataStoreName”: “Through whom capital culture decade another.”, “lastUpdatedTimestamp”: 1204069840, “lastUpdatedByUser”: {“id”: 833, “customerID”: 42, “userName”: “todd57”, “name”: “Andrea Schneider”}, “key”: “Fly cold center politics former stay.”, “value”: “Special itself bad billion.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Include story quality process itself.”, “messageTemplate”: “Feel full about.”, “field”: “The executive appear.”, “parameter”: {}, “timestamp”: 101179152}], “currentPage”: 477, “size”: 122}

`api.datastores.v1.store.store.` `get_entries_from_store`(dataStore: str, limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, userID: list = None, key: list = None, fromKey: str = None, toKey: str = None, startTimestamp: int = None, endTimestamp: int = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns datastore entries for the specified store, matching the search criteria. (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. userID (list) – Restrict search to entries which was last updated by specified users. key (list) – Restrict search to the specified key (entries). fromKey (str) – Restrict search to entries (map keys) which are greater than this key (including, by lexical order). toKey (str) – Restrict search to entries (map keys) which are less than this key (including, by lexical order). startTimestamp (int) – Restrict search to entries which are last updated after this timestamp (including). endTimestamp (int) – Restrict search to entries which are last updated before this timestamp (including). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 415, “limit”: 606, “responseCode”: 200, “count”: 937, “data”: [{“dataStoreName”: “Trip treatment admit leader appear agreement claim.”, “lastUpdatedTimestamp”: 1334306228, “lastUpdatedByUser”: {“id”: 480, “customerID”: 425, “userName”: “elizabeth02”, “name”: “Joseph Graham”}, “key”: “Amount subject phone.”, “value”: “Environment century against necessary west sea west.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Late Congress conference.”, “messageTemplate”: “Produce fear woman imagine wish each stock bring.”, “field”: “Stop program material ago enjoy drug.”, “parameter”: {}, “timestamp”: 702332927}], “currentPage”: 754, “size”: 532}

`api.datastores.v1.store.store.` `get_entries_from_store_simplified`(dataStore: str, customerID: list = None, key: list = None, offset: int = 0, limit: int = 25, includeDeleted: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns datastore entries for the specified store, matching query parameters. (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name customerID (list) – Limit search to entries for the specified customers key (list) – Limit search to the specified entry keys offset (int) – Skip a number of results limit (int) – Maximum number of returned results includeDeleted (bool) – Include deleted/expired keys
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 357, “limit”: 637, “responseCode”: 200, “count”: 464, “data”: [{“dataStoreName”: “Speak could ahead win big they member.”, “lastUpdatedTimestamp”: 1302479283, “lastUpdatedByUser”: {“id”: 239, “customerID”: 722, “userName”: “wendynorman”, “name”: “Gabriela Waller”}, “key”: “Democrat task thing.”, “value”: “Economic evening one manage go.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Nearly think prevent together thousand.”, “messageTemplate”: “Artist establish send close toward still rather.”, “field”: “Ground than friend find car whom offer huge.”, “parameter”: {}, “timestamp”: 1160534531}], “currentPage”: 442, “size”: 43}

`api.datastores.v1.store.store.` `get_single_entry`(dataStore: str, key: str, customerID: int = None, includeDeleted: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns the specified datastore entry for the specified store, or null if it does not exist (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name key (str) – Key to search customerID (int) – Search specified customer store for this key (default is users customer) includeDeleted (bool) – Include deleted/expired key
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 250, “limit”: 164, “responseCode”: 200, “count”: 985, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Win enjoy threat.”, “messageTemplate”: “Worry reveal subject owner.”, “field”: “Crime building much type.”, “parameter”: {}, “timestamp”: 1129090915}], “currentPage”: 410, “size”: 585}

`api.datastores.v1.store.store.` `put_data_store_entries`(dataStore: str, customerID: int = None, entries: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Updates the provided datastore entries for the specified store. (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name customerID (int) – ID of customer to bind data to. If not set, default is to bind to the current users customer (or none, if datastore is global) entries (list) – Entries to add
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 693, “limit”: 937, “responseCode”: 200, “count”: 347, “data”: [{“dataStoreName”: “Character group class listen.”, “lastUpdatedTimestamp”: 194121165, “lastUpdatedByUser”: {“id”: 818, “customerID”: 875, “userName”: “mary57”, “name”: “Timothy Arnold”}, “key”: “Foreign boy room.”, “value”: “Spend particularly career role pick.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Pressure officer TV who approach.”, “messageTemplate”: “Manager discover force case simply color born.”, “field”: “Chair thought perhaps large talk woman voice human.”, “parameter”: {}, “timestamp”: 898504134}], “currentPage”: 193, “size”: 620}

`api.datastores.v1.store.store.` `put_single_data_store_entry`(dataStore: str, key: str, customerID: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Adds the provided datastore entry for the specified store. To use for lists (key, no value) (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name key (str) – Datastore key to set customerID (int) – Specify datastore to put entry to (default is users customer)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 490, “limit”: 874, “responseCode”: 200, “count”: 932, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Threat space test fear vote heart.”, “messageTemplate”: “Experience little article laugh actually listen task magazine.”, “field”: “Other fear point.”, “parameter”: {}, “timestamp”: 730228335}], “currentPage”: 81, “size”: 633}

## Module contents